@@ -16,7 +16,7 @@ use POSIX;
 
 Readonly my $SOCKETTIMEOUT => 300;    # 300s or 5 min
 
-use version 0.9917; our $VERSION = version->declare('v2.2.0');
+use version 0.9917; our $VERSION = version->declare('v2.2.3');
 
 my $rtm = WebService::Hexonet::Connector::ResponseTemplateManager->getInstance();
 
@@ -24,12 +24,12 @@ my $rtm = WebService::Hexonet::Connector::ResponseTemplateManager->getInstance()
 sub new {
     my $class = shift;
     my $self  = bless {
-        socketURL    => 'https://coreapi.1api.net/api/call.cgi',
+        socketURL    => 'https://api.ispapi.net/api/call.cgi',
         debugMode    => 0,
         socketConfig => WebService::Hexonet::Connector::SocketConfig->new(),
         ua           => q{}
     }, $class;
-    $self->setURL('https://coreapi.1api.net/api/call.cgi');
+    $self->setURL('https://api.ispapi.net/api/call.cgi');
     $self->useLIVESystem();
     return $self;
 }
